[前][次][番号順一覧][スレッド一覧]

ruby-changes:29067

From: akr <ko1@a...>
Date: Fri, 7 Jun 2013 08:06:09 +0900 (JST)
Subject: [ruby-changes:29067] akr:r41119 (trunk): Arguments renamed.

akr	2013-06-07 08:05:59 +0900 (Fri, 07 Jun 2013)

  New Revision: 41119

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=41119

  Log:
    Arguments renamed.

  Modified files:
    trunk/bignum.c
    trunk/internal.h

Index: internal.h
===================================================================
--- internal.h	(revision 41118)
+++ internal.h	(revision 41119)
@@ -426,8 +426,8 @@ const char *rb_objspace_data_type_name(V https://github.com/ruby/ruby/blob/trunk/internal.h#L426
 VALUE rb_thread_io_blocking_region(rb_blocking_function_t *func, void *data1, int fd);
 
 /* bignum.c */
-void *rb_int_export(VALUE val, int *signp, size_t *wordcount_allocated, void *bufarg, size_t wordcount, int wordorder, size_t wordsize, int endian, size_t nails);
-VALUE rb_int_import(int sign, const void *bufarg, size_t wordcount, int wordorder, size_t wordsize, int endian, size_t nails);
+void *rb_int_export(VALUE val, int *signp, size_t *wordcount_allocated, void *words, size_t wordcount, int wordorder, size_t wordsize, int endian, size_t nails);
+VALUE rb_int_import(int sign, const void *words, size_t wordcount, int wordorder, size_t wordsize, int endian, size_t nails);
 
 /* io.c */
 void rb_maygvl_fd_fix_cloexec(int fd);
Index: bignum.c
===================================================================
--- bignum.c	(revision 41118)
+++ bignum.c	(revision 41119)
@@ -786,7 +786,7 @@ int_import_push_bits(int data, int numbi https://github.com/ruby/ruby/blob/trunk/bignum.c#L786
  *
  * [sign] signedness of the value.
  *   -1 for non-positive.  0 or 1 for non-negative.
  * [bufarg] buffer to import.
  * [wordcount] the size of given buffer as number of words.
  * [wordorder] order of words: 1 for most significant word first.  -1 for least significant word first.
  * [wordsize] the size of word as number of bytes.
@@ -796,11 +796,11 @@ int_import_push_bits(int data, int numbi https://github.com/ruby/ruby/blob/trunk/bignum.c#L796
  * This function returns the imported integer as Fixnum or Bignum.
  */
 VALUE
-rb_int_import(int sign, const void *bufarg, size_t wordcount, int wordorder, size_t wordsize, int endian, size_t nails)
+rb_int_import(int sign, const void *words, size_t wordcount, int wordorder, size_t wordsize, int endian, size_t nails)
 {
     VALUE num_bits, num_bdigits;
     VALUE result;
-    const unsigned char *buf = bufarg;
+    const unsigned char *buf = words;
 
     BDIGIT *dp;
     BDIGIT *de;
@@ -786,7 +786,7 @@ int_import_push_bits(int data, int numbi https://github.com/ruby/ruby/blob/trunk/bignum.c#L786
  * [sign] signedness of the value.
  *   -1 for non-positive.  0 or 1 for non-negative.
- * [bufarg] buffer to import.
+ * [words] buffer to import.
  * [wordcount] the size of given buffer as number of words.
  * [wordorder] order of words: 1 for most significant word first.  -1 for least significant word first.

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]